@@ -2,14 +2,11 @@ from sml2mqtt import __log__
 from sml2mqtt.__args__ import CMD_ARGS
 from sml2mqtt.__version__ import __version__
 
+
 # isort: split
 
 from sml2mqtt.config import CONFIG
 
 # isort: split
 
-from sml2mqtt import sml_value
-
 # isort: split
-
-import sml2mqtt.device
